"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  startRecord: true,
  stopRecord: true,
  startAudio: true,
  stopAudio: true
};
exports.startAudio = startAudio;
exports.startRecord = startRecord;
exports.stopAudio = stopAudio;
exports.stopRecord = stopRecord;
var _reactNative = require("react-native");
var _type = require("./type");
Object.keys(_type).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _type[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _type[key];
    }
  });
});
async function reqeustRecordAndStoragePermission() {
  try {
    const granted = await _reactNative.PermissionsAndroid.requestMultiple(['android.permission.RECORD_AUDIO', 'android.permission.WRITE_EXTERNAL_STORAGE']);
    if (Object.values(granted).every(value => value === 'granted')) return true;else return false;
  } catch (err) {
    return false;
  }
}
const LINKING_ERROR = `The package 'react-native-background-audio-record' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';
const BackgroundAudioRecord = _reactNative.NativeModules.BackgroundAudioRecord ? _reactNative.NativeModules.BackgroundAudioRecord : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
async function startRecord() {
  let {
    path,
    notificationConfig,
    audioConfig
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  try {
    if (_reactNative.Platform.OS === 'android') {
      if (await reqeustRecordAndStoragePermission()) {
        BackgroundAudioRecord.startRecord(path, audioConfig, notificationConfig);
      }
    }
  } catch (e) {
    console.warn(e);
  }
}
function stopRecord() {
  if (_reactNative.Platform.OS === 'android') {
    return BackgroundAudioRecord.stopRecord();
  }
}
function startAudio(path) {
  if (_reactNative.Platform.OS === 'android') {
    BackgroundAudioRecord.playAudio(path);
  }
}
function stopAudio() {
  if (_reactNative.Platform.OS === 'android') {
    BackgroundAudioRecord.stopAudio();
  }
}
//# sourceMappingURL=index.js.map